@@ -389,6 +389,6 @@ class __TwigTemplate_851da754b9bd88a457d656396ad49f22 extends Template
 
     public function getSourceContext(): Source
     {
-        return new Source("", "@MauticLead/Auditlog/_list.html.twig", "/var/www/html/staging-demo/app/bundles/LeadBundle/Resources/views/Auditlog/_list.html.twig");
+        return new Source("", "@MauticLead/Auditlog/_list.html.twig", "/var/www/html/mauticGIT-Test/app/bundles/LeadBundle/Resources/views/Auditlog/_list.html.twig");
     }
 }
